@@ -1,7 +1,7 @@
 import asyncio
 
 from mikro.datalayer import DataLayer, current_datalayer
-from mikro.scalars import ArrayInput, DataFrame, ParquetInput
+from mikro.scalars import XArrayInput, ParquetInput
 from rath.links.parsing import ParsingLink
 from rath.operation import Operation
 
@@ -69,10 +69,10 @@ class DataLayerUploadLink(ParsingLink):
         datalayer: DataLayer = current_datalayer.get()
 
         operation.variables = await apply_recursive(
-            datalayer.astore_array_input, operation.variables, ArrayInput
+            datalayer.astore_array_input, operation.variables, XArrayInput
         )
         operation.variables = await apply_recursive(
-            datalayer.astore_parquet_input, operation.variables, DataFrame
+            datalayer.astore_parquet_input, operation.variables, ParquetInput
         )
 
         return operation
